from __future__ import annotations

from typing import Any

from ..config.constants import API_PREFIX
from ..models.feeds import UserPerformance, UserPortfolio, UserProfile
from ._base import BaseRestClient


class UsersInfoClient(BaseRestClient):
    async def search_users(
        self,
        *,
        search_text: str | None = None,
        page: int | None = None,
        page_size: int | None = None,
    ) -> Any:
        query: dict[str, Any] = {}
        if search_text is not None:
            query["searchText"] = search_text
        if page is not None:
            query["page"] = page
        if page_size is not None:
            query["pageSize"] = page_size
        return await self._get(f"{API_PREFIX}/users-info/search", query or None)

    async def get_user_profile(self, user_id: int) -> UserProfile:
        data = await self._get(f"{API_PREFIX}/users-info/{user_id}/profile")
        return UserProfile.model_validate(data)

    async def get_user_portfolio(self, user_id: int) -> UserPortfolio:
        data = await self._get(f"{API_PREFIX}/users-info/{user_id}/portfolio")
        return UserPortfolio.model_validate(data)

    async def get_user_trade_info(self, user_id: int) -> Any:
        return await self._get(f"{API_PREFIX}/users-info/{user_id}/trade-info")

    async def get_user_performance(self, user_id: int) -> UserPerformance:
        data = await self._get(f"{API_PREFIX}/users-info/{user_id}/performance")
        return UserPerformance.model_validate(data)

    async def get_user_performance_by_period(self, user_id: int, period: str) -> Any:
        return await self._get(f"{API_PREFIX}/users-info/{user_id}/performance/{period}")



from __future__ import annotations

from typing import Any, cast

from ..config.constants import API_PREFIX
from ._base import BaseRestClient


class DiscoveryClient(BaseRestClient):
    async def get_curated_lists(self) -> list[Any]:
        return cast(list[Any], await self._get(f"{API_PREFIX}/watchlists/curated"))

    async def get_market_recommendations(self) -> list[Any]:
        return cast(list[Any], await self._get(f"{API_PREFIX}/watchlists/recommendations"))



from __future__ import annotations

from typing import Any

from ..config.constants import API_PREFIX
from ..models.feeds import FeedResponse
from ._base import BaseRestClient


class FeedsClient(BaseRestClient):
    async def create_post(self, content: str, instrument_id: int | None = None) -> Any:
        body: dict[str, Any] = {"content": content}
        if instrument_id is not None:
            body["instrumentId"] = instrument_id
        return await self._post(f"{API_PREFIX}/feeds/posts", body)

    async def get_instrument_feed(
        self,
        instrument_id: int,
        *,
        page: int | None = None,
        page_size: int | None = None,
    ) -> FeedResponse:
        query: dict[str, Any] = {}
        if page is not None:
            query["page"] = page
        if page_size is not None:
            query["pageSize"] = page_size
        data = await self._get(f"{API_PREFIX}/feeds/instruments/{instrument_id}", query or None)
        return FeedResponse.model_validate(data)

    async def get_user_feed(
        self,
        user_id: int,
        *,
        page: int | None = None,
        page_size: int | None = None,
    ) -> FeedResponse:
        query: dict[str, Any] = {}
        if page is not None:
            query["page"] = page
        if page_size is not None:
            query["pageSize"] = page_size
        data = await self._get(f"{API_PREFIX}/feeds/users/{user_id}", query or None)
        return FeedResponse.model_validate(data)



from __future__ import annotations

from ..config.constants import API_PREFIX
from ..models.feeds import CopierInfo
from ._base import BaseRestClient


class PiDataClient(BaseRestClient):
    async def get_copiers_public_info(self, user_id: int) -> CopierInfo:
        data = await self._get(f"{API_PREFIX}/pi-data/copiers/{user_id}")
        return CopierInfo.model_validate(data)
